#ifndef EXPORTWINDOW_H
#define EXPORTWINDOW_H

#include <QMainWindow>
#include <QMaemo5EditBar>
#include <QtGui>
#include "xml.h"
#include "qmaemo5rotator.h"

class ExportWindow : public QMainWindow
{
    Q_OBJECT
public:
    explicit ExportWindow(QWidget *parent = 0);
    void loadExercises(QString grp);
    QMaemo5Rotator *exwRot;
signals:

private:
    XML *xml;

    QMaemo5EditBar *editBar;
    QListView *lstExercises;
    QStandardItemModel *model;

    QString group;

private slots:
    void exportSelected();
};

#endif // EXPORTWINDOW_H
